@@ -1,9 +1,8 @@
 #' Retrieve the taxonomic hierarchy for a given taxon ID.
 #'
 #' @export
-#' @import XML RCurl plyr
 #'
-#' @param x character; taxons to query.
+#' @param x Vector of taxa names (character) or IDs (character or numeric) to query.
 #' @param db character; database to query. either \code{ncbi}, \code{itis},
 #'    \code{eol}, \code{col}, \code{tropicos}, \code{gbif}, or \code{nbn}.
 #' @param id character; identifiers, returned by \code{\link[taxize]{get_tsn}},
@@ -44,7 +43,19 @@
 #'    \code{\link[taxize]{get_tpsid}}, \code{\link[taxize]{get_gbifid}}
 #'
 #' @examples \dontrun{
-#' # Plug in taxon names directly
+#' # Plug in taxon IDs
+#' classification(9606, db = 'ncbi')
+#' classification(c(9606, 55062), db = 'ncbi')
+#' classification(129313, db = 'itis')
+#' classification(57361017, db = 'eol')
+#' classification(c(2704179, 2441176), db = 'gbif')
+#' classification(25509881, db = 'tropicos')
+#' classification("NBNSYS0000004786", db = 'nbn')
+#' ## works the same if IDs are in class character
+#' classification(c("2704179", "2441176"), db = 'gbif')
+#'
+#' # Plug in taxon names
+#' ## in this case, we use get_*() fxns internally to first get taxon IDs
 #' classification(c("Chironomus riparius", "aaa vva"), db = 'ncbi')
 #' classification(c("Chironomus riparius", "aaa vva"), db = 'ncbi', verbose=FALSE)
 #' classification(c("Chironomus riparius", "aaa vva"), db = 'itis')
@@ -138,46 +149,52 @@ classification.default <- function(x, db = NULL, callopts=list(), return_id = TR
   nstop(db)
   switch(db,
          itis = {
-           id <- process_ids(x, get_tsn, rows = rows, ...)
-           setNames(classification(id, callopts=callopts, return_id=return_id, ...), x)
+           id <- process_ids(x, db, get_tsn, rows = rows, ...)
+           setNames(classification(id, callopts = callopts, return_id = return_id, ...), x)
          },
          ncbi = {
-           id <- process_ids(x, get_uid, rows = rows, ...)
-           setNames(classification(id, callopts=callopts, return_id=return_id, ...), x)
+           id <- process_ids(x, db, get_uid, rows = rows, ...)
+           setNames(classification(id, callopts = callopts, return_id = return_id, ...), x)
          },
          eol = {
-           id <- process_ids(x, get_eolid, rows = rows, ...)
-           setNames(classification(id, callopts=callopts, return_id=return_id, ...), x)
+           id <- process_ids(x, db, get_eolid, rows = rows, ...)
+           setNames(classification(id, callopts = callopts, return_id = return_id, ...), x)
          },
          col = {
-           id <- process_ids(x, get_colid, rows = rows, ...)
-           setNames(classification(id, callopts=callopts, return_id=return_id, ...), x)
+           id <- process_ids(x, db, get_colid, rows = rows, ...)
+           setNames(classification(id, callopts = callopts, return_id = return_id, ...), x)
          },
          tropicos = {
-           id <- process_ids(x, get_tpsid, rows = rows, ...)
-           setNames(classification(id, callopts=callopts, return_id=return_id, ...), x)
+           id <- process_ids(x, db, get_tpsid, rows = rows, ...)
+           setNames(classification(id, callopts = callopts, return_id = return_id, ...), x)
          },
          gbif = {
-           id <- process_ids(x, get_gbifid, rows = rows, ...)
-           setNames(classification(id, callopts=callopts, return_id=return_id, ...), x)
+           id <- process_ids(x, db, get_gbifid, rows = rows, ...)
+           setNames(classification(id, callopts = callopts, return_id = return_id, ...), x)
          },
          nbn = {
-           id <- process_ids(x, get_nbnid, rows = rows, ...)
-           setNames(classification(id, callopts=callopts, return_id=return_id, ...), x)
+           id <- process_ids(x, db, get_nbnid, rows = rows, ...)
+           setNames(classification(id, callopts = callopts, return_id = return_id, ...), x)
          },
-         stop("the provided db value was not recognised", call.=FALSE)
+         stop("the provided db value was not recognised", call. = FALSE)
   )
 }
 
-process_ids <- function(input, fxn, ...){
-  g <- tryCatch(as.numeric(as.character(input)), warning=function(e) e)
-  if(is(g,"numeric")){
-    id <- input
-    class(id) <- "tsn"
+process_ids <- function(input, db, fxn, ...){
+  g <- tryCatch(as.numeric(as.character(input)), warning = function(e) e)
+  if (is(g,"numeric") || is.character(input) && grepl("N[HB]", input)) {
+    as_fxn <- switch(db,
+           itis = as.tsn,
+           ncbi = as.uid,
+           eol = as.eolid,
+           col = as.colid,
+           tropicos = as.tpsid,
+           gbif = as.gbifid,
+           nbn = as.nbnid)
+    as_fxn(input, check = FALSE)
   } else {
-    id <- eval(fxn)(input, ...)
+    eval(fxn)(input, ...)
   }
-  id
 }
 
 #' @export
@@ -213,7 +230,6 @@ classification.uid <- function(id, callopts = list(), return_id = TRUE, ...) {
       baseurl <- "http://eutils.ncbi.nlm.nih.gov/entrez/eutils/efetch.fcgi?db=taxonomy"
       ID <- paste("ID=", x, sep = "")
       searchurl <- paste(baseurl, ID, sep = "&")
-      # tt <- getURL(searchurl)
       tt <- GET(searchurl, callopts)
       ttp <- xmlTreeParse(tt, useInternalNodes = TRUE)
       out <- data.frame(name = xpathSApply(ttp, "//TaxaSet/Taxon/LineageEx/Taxon/ScientificName", xmlValue),
@@ -241,23 +257,23 @@ classification.uid <- function(id, callopts = list(), return_id = TRUE, ...) {
 classification.eolid <- function(id, key = NULL, callopts = list(), return_id = TRUE, ...) {
   common_names = synonyms = NULL
   fun <- function(x){
-    if(is.na(x)){
+    if (is.na(x)) {
       out <- NA
     } else {
       url = 'http://eol.org/api/hierarchy_entries/1.0/'
       key <- getkey(key, "eolApiKey")
-      urlget <- paste(url, x, '.json', sep="")
-      args <- compact(list(common_names=common_names, synonyms=synonyms))
-      tt <- GET(urlget, query=args, callopts)
+      urlget <- paste(url, x, '.json', sep = "")
+      args <- tc(list(common_names = common_names, synonyms = synonyms))
+      tt <- GET(urlget, query = args, callopts)
       stop_for_status(tt)
       res <- content(tt)
-      if(length(res$ancestors)==0){
+      if (length(res$ancestors) == 0) {
         return(sprintf("No hierarchy information for %s", x))
       } else {
         out <- do.call(rbind.fill, lapply(res$ancestors, data.frame, stringsAsFactors = FALSE))[,c('scientificName','taxonRank', 'taxonID')]
         # add querried taxon
         tr <- res$taxonRank
-        out <- rbind(out, c(res$scientificName, if( is.null(tr) ) NA else tr, x))
+        out <- rbind(out, c(res$scientificName, if ( is.null(tr) ) NA else tr, x))
         names(out) <- c('name', 'rank', 'id')
         # Optionally return id of lineage
         if (!return_id) out <- out[, c('name', 'rank')]
@@ -267,7 +283,7 @@ classification.eolid <- function(id, key = NULL, callopts = list(), return_id =
   }
   out <- lapply(id, fun)
   names(out) <- id
-  structure(out, class='classification', db='eol')
+  structure(out, class = 'classification', db = 'eol')
 }
 
 #' @export
@@ -275,11 +291,11 @@ classification.eolid <- function(id, key = NULL, callopts = list(), return_id =
 classification.colid <- function(id, start = NULL, checklist = NULL, callopts = list(), return_id = TRUE, ...) {
   fun <- function(x, callopts){
     # return NA if NA is supplied
-    if(is.na(x)){
+    if (is.na(x)) {
       out <- NA
     } else {
       url <- "http://www.catalogueoflife.org/col/webservice"
-      if(!is.null(checklist)){
+      if (!is.null(checklist)) {
         cc <- match.arg(checklist, choices = c(2012, 2011, 2010, 2009, 2008, 2007))
         if (cc %in% c(2012, 2011, 2010)) {
           url <- gsub("col", paste("annual-checklist/", cc, sep = ""), url)
@@ -289,7 +305,7 @@ classification.colid <- function(id, start = NULL, checklist = NULL, callopts =
         }
       }
 
-      args <- compact(list(id = x, response = "full", start = start))
+      args <- tc(list(id = x, response = "full", start = start))
       out <- GET(url, query = args, callopts)
       stop_for_status(out)
       tt <- xmlParse(content(out, "text"))
@@ -316,17 +332,17 @@ classification.colid <- function(id, start = NULL, checklist = NULL, callopts =
 #' @rdname classification
 classification.tpsid <- function(id, key = NULL, callopts = list(), return_id = TRUE, ...) {
   fun <- function(x, callopts){
-    if(is.na(x)) {
+    if (is.na(x)) {
       out <- NA
     } else {
       url <- sprintf('http://services.tropicos.org/Name/%s/HigherTaxa', x)
       key <- getkey(key, "tropicosApiKey")
-      args <- taxize_compact(list(format='json', apikey=key))
+      args <- tc(list(format = 'json', apikey = key))
       tt <- GET(url, query = args, callopts)
       stop_for_status(tt)
       out <- content(tt)
-      if(names(out[[1]])[[1]] == "Error"){
-        out <- data.frame(ScientificName=NA, Rank=NA)
+      if (names(out[[1]])[[1]] == "Error") {
+        out <- data.frame(ScientificName = NA, Rank = NA)
       } else {
         out <- do.call(rbind.fill, lapply(out, data.frame))[,c('ScientificName','Rank', 'NameId')]
       }
@@ -338,21 +354,23 @@ classification.tpsid <- function(id, key = NULL, callopts = list(), return_id =
   }
   out <- lapply(id, fun, callopts = callopts)
   names(out) <- id
-  structure(out, class='classification', db='tropicos')
+  structure(out, class = 'classification', db = 'tropicos')
 }
 
 #' @export
 #' @rdname classification
 classification.gbifid <- function(id, callopts = list(), return_id = TRUE, ...) {
   fun <- function(x, callopts){
-    if(is.na(x)) {
+    if (is.na(x)) {
       out <- NA
     } else {
-      out <- suppressWarnings(tryCatch(gbif_name_usage(key = x, callopts = callopts), error=function(e) e))
-      if(is(out, "simpleError")){ NA } else {
+      out <- suppressWarnings(tryCatch(gbif_name_usage(key = x, callopts = callopts), error = function(e) e))
+      if (is(out, "simpleError")) {
+        NA
+      } else {
         nms <- ldply(out[c('kingdom','phylum','class','order','family','genus','species')])
         keys <- unname(unlist(out[paste0(c('kingdom','phylum','class','order','family','genus','species'), "Key")]))
-        df <- data.frame(name=nms$V1, rank=nms$.id, id=keys)
+        df <- data.frame(name = nms$V1, rank = nms$.id, id = keys)
 
         # Optionally return id of lineage
         if (!return_id) df[, c('name', 'rank')] else df
@@ -371,8 +389,10 @@ classification.nbnid <- function(id, callopts = list(), return_id = TRUE, ...) {
     if (is.na(x)) {
       out <- NA
     } else {
-      out <- suppressWarnings(tryCatch(nbn_classification(id=x, callopts), error=function(e) e))
-      if (is(out, "simpleError")){ NA } else {
+      out <- suppressWarnings(tryCatch(nbn_classification(id = x, callopts), error = function(e) e))
+      if (is(out, "simpleError")) {
+        NA
+      } else {
         out <- out[ , c('name','rank', 'taxonVersionKey')]
         names(out) <- c('name', 'rank', 'id')
         # Optionally return id of lineage
@@ -388,8 +408,7 @@ classification.nbnid <- function(id, callopts = list(), return_id = TRUE, ...) {
 
 #' @export
 #' @rdname classification
-classification.ids <- function(id, ...)
-{
+classification.ids <- function(id, ...) {
   fun <- function(x, ...){
     # return NA if NA is supplied
     if (all(is.na(x))) {
@@ -399,18 +418,17 @@ classification.ids <- function(id, ...)
     }
     return(out)
   }
-  structure(lapply(id, fun, ...), class='classification_ids')
+  structure(lapply(id, fun, ...), class = 'classification_ids')
 }
 
 #' @export
 #' @rdname classification
-cbind.classification <- function(x)
-{
-  gethiernames <- function(x){
+cbind.classification <- function(x) {
+  gethiernames <- function(x) {
     x$name <- as.character(x$name)
     x$rank <- as.character(x$rank)
     values <- setNames(data.frame(t(x[,'name']), stringsAsFactors = FALSE), tolower(x[,'rank']))
-    if("id" %in% names(x)){
+    if ("id" %in% names(x)) {
       x$id <- as.character(x$id)
       ids <- setNames(data.frame(t(x[,'id']), stringsAsFactors = FALSE), paste0(tolower(x[,'rank']),"_id") )
       data.frame(values, ids)
@@ -428,12 +446,11 @@ cbind.classification <- function(x)
 
 #' @export
 #' @rdname classification
-rbind.classification <- function(x)
-{
+rbind.classification <- function(x) {
   input <- x
   db <- attr(input, "db")
   x <- input[vapply(x, class, "") %in% "data.frame"]
-  for(i in seq_along(x)){
+  for (i in seq_along(x)) {
     x[[i]]$query <- names(x[i])
   }
   df <- do.call(rbind.fill, x)
@@ -443,8 +460,7 @@ rbind.classification <- function(x)
 
 #' @export
 #' @rdname classification
-cbind.classification_ids <- function(...)
-{
+cbind.classification_ids <- function(...) {
   input <- c(...)
   # remove non-data.frames
   input <- input[vapply(input, function(x) class(x[[1]]), "") %in% "data.frame"]
@@ -453,7 +469,7 @@ cbind.classification_ids <- function(...)
     x$name <- as.character(x$name)
     x$rank <- as.character(x$rank)
     values <- setNames(data.frame(t(x[,'name']), stringsAsFactors = FALSE), tolower(x[,'rank']))
-    if("id" %in% names(x)){
+    if ("id" %in% names(x)) {
       x$id <- as.character(x$id)
       ids <- setNames(data.frame(t(x[,'id']), stringsAsFactors = FALSE), paste0(tolower(x[,'rank']),"_id") )
       data.frame(values, ids)
@@ -469,31 +485,30 @@ cbind.classification_ids <- function(...)
       tmp
     })
   )
-  move_col(tt=dat, y=c('query','db'))
+  move_col(tt = dat, y = c('query','db'))
 }
 
 move_col <- function(tt, y){
-  tt[ c(names(tt)[ - sapply(y, function(m) grep(m, names(tt))) ], y) ]
+  tt[ c(names(tt)[ -sapply(y, function(m) grep(m, names(tt))) ], y) ]
 }
 
 #' @export
 #' @rdname classification
-rbind.classification_ids <- function(...)
-{
+rbind.classification_ids <- function(...) {
   input <- c(...)
   # remove non-data.frames
   input <- input[vapply(input, function(x) class(x[[1]]), "") %in% "data.frame"]
 
   df <- lapply(input, function(x){
     coll <- list()
-    for(i in seq_along(x)){
+    for (i in seq_along(x)) {
       coll[[i]] <- data.frame(names(x[i]), x[i][[1]], stringsAsFactors = FALSE)
     }
     coll
   })
 
   get <- list()
-  for(i in seq_along(df[[1]])){
+  for (i in seq_along(df[[1]])) {
     tmp <- do.call(rbind, lapply(df, "[[", i))
     source2 <- gsub("\\.[0-9]+", "", row.names(tmp))
     row.names(tmp) <- NULL
@@ -502,6 +517,6 @@ rbind.classification_ids <- function(...)
     get[[i]] <- tmp
   }
 
-  tt <- if(length(get) == 1) get[[1]] else do.call(rbind.fill, get)
+  tt <- if (length(get) == 1) get[[1]] else do.call(rbind.fill, get)
   move_col(tt, c('query','db'))
 }
