@@ -1,6 +1,5 @@
 #' Parse taxon names using the GBIF name parser.
 #'
-#' @import httr plyr jsonlite
 #' @param scientificname A character vector of scientific names.
 #' @return A \code{data.frame} containing fields extracted from parsed
 #' taxon names. Fields returned are the union of fields extracted from
@@ -20,12 +19,11 @@
 gbif_parse <- function(scientificname) {
   url <- "http://api.gbif.org/v1/parser/name"
   tt <- POST(url,
-            config=c(add_headers('Content-Type' =
+            config = c(add_headers('Content-Type' =
                                    'application/json')),
-            body=jsonlite::toJSON(scientificname))
+            body = jsonlite::toJSON(scientificname))
   stop_for_status(tt)
   res <- content(tt)
   tmp <- do.call(rbind.fill, lapply(res, as.data.frame))
-  names(tmp) <- tolower(names(tmp))
-  tmp
+  setNames(tmp, tolower(names(tmp)))
 }
