@@ -1,6 +1,5 @@
 #' Get the Catalogue of Life ID from taxonomic names.
 #'
-#' @import plyr RCurl
 #' @param sciname character; scientific name.
 #' @param ask logical; should get_colid be run in interactive mode?
 #' If TRUE and more than one ID is found for the species, the user is asked for
@@ -34,6 +33,7 @@
 #' and \code{rank} are not used in the search to the data provider, but are used in filtering
 #' the data down to a subset that is closer to the target you want. For all these parameters,
 #' you can use regex strings since we use \code{\link{grep}} internally to match.
+#' Filtering narrows down to the set that matches your query, and removes the rest.
 #'
 #' @seealso \code{\link[taxize]{get_tsn}}, \code{\link[taxize]{get_colid}},
 #' \code{\link[taxize]{get_tpsid}}, \code{\link[taxize]{get_eolid}}
@@ -79,18 +79,19 @@
 #' # Convert a uid without class information to a uid class
 #' as.colid(get_colid("Chironomus riparius")) # already a uid, returns the same
 #' as.colid(get_colid(c("Chironomus riparius","Pinus contorta"))) # same
-#' as.colid(8663146) # numeric
-#' as.colid(c(8663146,19736162,18158318)) # numeric vector, length > 1
-#' as.colid("19736162") # character
-#' as.colid(c("8663146","19736162","18158318")) # character vector, length > 1
-#' as.colid(list("8663146","19736162","18158318")) # list, either numeric or character
+#' as.colid("714831352ad94741e4321eccdeb29f58") # character
+#' # character vector, length > 1
+#' as.colid(c("714831352ad94741e4321eccdeb29f58", "3b35900f74ff6e4b073ddb95c32b1f8d"))
+#' # list, either numeric or character
+#' as.colid(list("714831352ad94741e4321eccdeb29f58", "3b35900f74ff6e4b073ddb95c32b1f8d"))
 #' ## dont check, much faster
-#' as.colid("8663146", check=FALSE)
-#' as.colid(8663146, check=FALSE)
-#' as.colid(c("8663146","19736162","18158318"), check=FALSE)
-#' as.colid(list("8663146","19736162","18158318"), check=FALSE)
+#' as.colid("714831352ad94741e4321eccdeb29f58", check=FALSE)
+#' as.colid(c("714831352ad94741e4321eccdeb29f58", "3b35900f74ff6e4b073ddb95c32b1f8d"),
+#'  check=FALSE)
+#' as.colid(list("714831352ad94741e4321eccdeb29f58", "3b35900f74ff6e4b073ddb95c32b1f8d"),
+#'  check=FALSE)
 #'
-#' (out <- as.colid(c(8663146,19736162,18158318)))
+#' (out <- as.colid(c("714831352ad94741e4321eccdeb29f58", "3b35900f74ff6e4b073ddb95c32b1f8d")))
 #' data.frame(out)
 #' as.colid( data.frame(out) )
 #'
@@ -115,6 +116,7 @@ get_colid <- function(sciname, ask = TRUE, verbose = TRUE, rows = NA,
   fun <- function(sciname, ask, verbose, rows, ...) {
     mssg(verbose, "\nRetrieving data for taxon '", sciname, "'\n")
     df <- col_search(name = sciname, response = "full", ...)[[1]]
+    df <- df[, names(df) %in% c("name","rank","id","name_status","kingdom","family")]
     df <- sub_rows(df, rows)
 
     rank_taken <- NA
@@ -150,6 +152,7 @@ get_colid <- function(sciname, ask = TRUE, verbose = TRUE, rows = NA,
           df <- filt(df, "family", family)
           df <- filt(df, "rank", rank)
           id <- df$colid
+          if (NROW(df) > 1) rownames(df) <- 1:nrow(df)
           if (length(id) == 1) {
             rank_taken <- as.character(df$rank)
             att <- "found"
@@ -195,12 +198,14 @@ get_colid <- function(sciname, ask = TRUE, verbose = TRUE, rows = NA,
   if ( !all(is.na(ids)) ) {
     urls <- sapply(out, function(z){
       if (!is.na(z[['id']])) {
-        if (tolower(z['rank']) == "Species") {
+        if (tolower(z['rank']) == "species") {
           sprintf('http://www.catalogueoflife.org/col/details/species/id/%s', z[['id']])
         } else {
           sprintf('http://www.catalogueoflife.org/col/browse/tree/id/%s', z[['id']])
         }
-      } else { NA }
+      } else {
+        NA
+      }
     })
     attr(ids, 'uri') <- unlist(urls)
   }
@@ -217,19 +222,15 @@ as.colid.colid <- function(x, check=TRUE) x
 
 #' @export
 #' @rdname get_colid
-as.colid.character <- function(x, check=TRUE) if(length(x) == 1) make_colid(x, check) else collapse(x, make_colid, "colid", check=check)
+as.colid.character <- function(x, check=TRUE) if (length(x) == 1) make_colid(x, check) else collapse(x, make_colid, "colid", check = check)
 
 #' @export
 #' @rdname get_colid
-as.colid.list <- function(x, check=TRUE) if(length(x) == 1) make_colid(x, check) else collapse(x, make_colid, "colid", check=check)
+as.colid.list <- function(x, check=TRUE) if (length(x) == 1) make_colid(x, check) else collapse(x, make_colid, "colid", check = check)
 
 #' @export
 #' @rdname get_colid
-as.colid.numeric <- function(x, check=TRUE) as.colid(as.character(x), check)
-
-#' @export
-#' @rdname get_colid
-as.colid.data.frame <- function(x, check=TRUE) structure(x$ids, class="colid", match=x$match, uri=x$uri)
+as.colid.data.frame <- function(x, check=TRUE) structure(x$ids, class = "colid", match = x$match, uri = x$uri)
 
 #' @export
 #' @rdname get_colid
@@ -259,6 +260,6 @@ get_colid_ <- function(sciname, verbose = TRUE, rows = NA){
 
 get_colid_help <- function(sciname, verbose, rows){
   mssg(verbose, "\nRetrieving data for taxon '", sciname, "'\n")
-  df <- col_search(name=sciname)[[1]]
-  if(NROW(df) == 0) NULL else sub_rows(df, rows)
+  df <- col_search(name = sciname)[[1]]
+  if (NROW(df) == 0) NULL else sub_rows(df, rows)
 }
