@@ -4,7 +4,6 @@
 #' to search for names.
 #'
 #' @export
-#' @import plyr
 #' @param searchterm character; A vector of common or scientific names.
 #' @param searchtype character; One of 'scientific' or 'common', or any unique abbreviation
 #' @param ask logical; should get_tsn be run in interactive mode?
@@ -34,6 +33,7 @@
 #' provider, but are used in filtering the data down to a subset that is closer to the
 #' target you want.  For all these parameters,
 #' you can use regex strings since we use \code{\link{grep}} internally to match.
+#' Filtering narrows down to the set that matches your query, and removes the rest.
 #'
 #' @seealso \code{\link[taxize]{get_uid}}, \code{\link[taxize]{ubio_search}}
 #'
@@ -183,6 +183,7 @@ get_ubioid <- function(searchterm, searchtype = "scientific", ask = TRUE, verbos
           if (!is.null(family) || !is.null(rank)) {
             ubio_df <- filt(ubio_df, "family", family)
             if (searchtype == "scientific") ubio_df <- filt(ubio_df, "rank", rank)
+            if (NROW(ubio_df) > 1) rownames(ubio_df) <- 1:nrow(ubio_df)
             ubioid <- id <- ubio_df$ubioid
             if (length(id) == 1) {
               att <- "found"
