@@ -30,7 +30,7 @@ nbn_search <- function(q, prefered = FALSE, order = 'asc', sort = NULL, start =
   rows = 25, taxonOutputGroupKey = NULL, all = FALSE, ...)
 {
   url <- "https://data.nbn.org.uk/api/search/taxa"
-  args <- taxize_compact(list(q = q, prefered = prefered, order = order, sort = sort, start = start,
+  args <- tc(list(q = q, prefered = prefered, order = order, sort = sort, start = start,
                               rows = rows, taxonOutputGroupKey = taxonOutputGroupKey))
   if(all){
     args$rows <- 0
@@ -41,7 +41,7 @@ nbn_search <- function(q, prefered = FALSE, order = 'asc', sort = NULL, start =
 }
 
 nbn_GET <- function(url, args, ...){
-  res <- GET(url, query = args, ...)
+  res <- GET(url, query = argsnull(args), ...)
   stop_for_status(res)
   tt <- content(res, as = "text")
   json <- jsonlite::fromJSON(tt, FALSE)
