@@ -1,6 +1,5 @@
 #' Query Phylomatic for a phylogenetic tree.
 #'
-#' @import httr ape stringr
 #' @export
 #'
 #' @param taxa Phylomatic format input of taxa names.
@@ -21,6 +20,7 @@
 #' @param db One of "ncbi", "itis", or "apg". If there are gymnosperms in your taxa
 #' list, don't use apg, intead use ncbi or itis.
 #' @param verbose Print messages (default: TRUE).
+#' @param ... Curl options passed on to \code{\link[httr]{GET}} or \code{\link[httr]{POST}}
 #' @details Use the web interface here \url{http://phylodiversity.net/phylomatic/}
 #' @return Newick formatted tree or nexml text.
 #' @rdname phylomatic_tree-deprecated
@@ -71,60 +71,68 @@
 
 phylomatic_tree <- function(taxa, taxnames = TRUE, get = 'GET',
   informat = "newick", method = "phylomatic", storedtree = "R20120829", treeuri = NULL,
-  taxaformat = "slashpath", outformat = "newick", clean = "true", db="apg", verbose=TRUE)
+  taxaformat = "slashpath", outformat = "newick", clean = "true", db="apg", verbose=TRUE, ...)
 {
-  .Deprecated(msg="This function is deprecated - will be removed in a future version of this pacakge. See ?`taxize-deprecated`")
+  .Deprecated(msg = "This function is deprecated - will be removed in a future version of this pacakge. See ?`taxize-deprecated`")
 
   url = "http://phylodiversity.net/phylomatic/pmws"
 
-  if(taxnames){
-    dat_ <- phylomatic_format(taxa, format='isubmit', db=db)
+  if (taxnames) {
+    dat_ <- phylomatic_format(taxa, format = 'isubmit', db = db)
 
     checknas <- sapply(dat_, function(x) strsplit(x, "/")[[1]][1])
     checknas2 <- checknas[match("na", checknas)]
-    if(is.numeric(checknas2))
+    if (is.numeric(checknas2)) {
       stop(sprintf("A family was not found for the following taxa:\n %s \n\n try setting taxnames=FALSE, and passing in a vector of strings, like \n%s",
-                   paste(sapply(dat_, function(x) strsplit(x, "/")[[1]][3])[match("na", checknas)], collapse=", "),
+                   paste(sapply(dat_, function(x) strsplit(x, "/")[[1]][3])[match("na", checknas)], collapse = ", "),
                    'phylomatic_tree(taxa = c("asteraceae/taraxacum/taraxacum_officinale", "ericaceae/gaylussacia/gaylussacia_baccata", "ericaceae/vaccinium/vaccinium_pallidum"), taxnames=FALSE, parallel=FALSE)'
       ))
+    }
+  } else {
+    dat_ <- taxa
+  }
 
-  } else { dat_ <- taxa }
-
-  if (length(dat_) > 1) { dat_ <- paste(dat_, collapse = "\n") } else { dat_ <- dat_ }
+  if (length(dat_) > 1) {
+    dat_ <- paste(dat_, collapse = "\n")
+  }
 
   # Only one of storedtree or treeuri
-  if(!is.null(treeuri)) storedtree <- NULL
+  if (!is.null(treeuri)) storedtree <- NULL
 
-  args <- taxize_compact(list(taxa = dat_, informat = informat, method = method,
+  args <- tc(list(taxa = dat_, informat = informat, method = method,
                        storedtree = storedtree, treeuri = treeuri, taxaformat = taxaformat,
                        outformat = outformat, clean = clean))
 
   if (get == 'POST') {
-#     tt <- POST(url, body=list(taxa=dat_), query=args, multipart=FALSE)
-    out <- postForm(url, .params=args, style = "POST")
+    # tt <- POST(url, body = list(taxa = dat_), query=args, multipart=FALSE)
+    ff <- tempfile(fileext = ".txt")
+    argstofile <- paste(names(args), args, collapse = "&", sep = "=")
+    writeLines(argstofile, con = ff)
+    tt <- POST(url, body = upload_file(ff), ...)
+    out <- content(tt, "text")
   } else if (get == 'GET') {
-    tt <- GET(url, query=args)
-    if(tt$status_code == 414){
+    tt <- GET(url, query = args, ...)
+    if (tt$status_code == 414) {
       stop("(414) Request-URI Too Long - Use get='POST' in your function call", call. = FALSE)
     } else {
       stop_for_status(tt)
     }
-    out <- content(tt, as="text")
-  } else
-  { stop("Error: get must be one of 'POST' or 'GET'") }
+    out <- content(tt, as = "text")
+  } else {
+    stop("Error: get must be one of 'POST' or 'GET'")
+  }
 
-  if(grepl("No taxa in common", out)){
+  if (grepl("No taxa in common", out)) {
     stop(out)
-  } else
-  {
+  } else {
     # parse out missing taxa note
-    if(grepl("\\[NOTE: ", out)){
+    if (grepl("\\[NOTE: ", out)) {
       taxa_na <- str_extract(out, "NOTE:.+")
       taxa_na2 <- str_extract(taxa_na, ":\\s[A-Za-z].+")
       taxa_na2 <- strsplit(taxa_na2, ",")[[1]][-length(strsplit(taxa_na2, ",")[[1]])]
       taxa_na2 <- gsub(":|\\s", "", taxa_na2)
-      taxa_na2 <- sapply(taxa_na2, function(x) strsplit(x, "/")[[1]][[3]], USE.NAMES=FALSE)
-      taxa_na2 <- taxize_capwords(gsub("_", " ", taxa_na2), onlyfirst=TRUE)
+      taxa_na2 <- sapply(taxa_na2, function(x) strsplit(x, "/")[[1]][[3]], USE.NAMES = FALSE)
+      taxa_na2 <- taxize_capwords(gsub("_", " ", taxa_na2), onlyfirst = TRUE)
 
       mssg(verbose, taxa_na)
       out <- gsub("\\[NOTE:.+", ";\n", out)
@@ -132,12 +140,7 @@ phylomatic_tree <- function(taxa, taxnames = TRUE, get = 'GET',
         taxa_na2 <- NULL
     }
 
-    outformat <- match.arg(outformat, choices=c("nexml",'newick'))
-    getnewick <- function(x){
-      tree <- gsub("\n", "", x[[1]])
-      read.tree(text = colldouble(tree))
-    }
-
+    outformat <- match.arg(outformat, choices = c("nexml",'newick'))
     res <- switch(outformat,
            nexml = out,
            newick = getnewick(out))
@@ -149,24 +152,32 @@ phylomatic_tree <- function(taxa, taxnames = TRUE, get = 'GET',
 
 collapse_double_root <- function(y) {
   temp <- str_split(y, ")")[[1]]
-  double <- c(length(temp)-1, length(temp))
+  double <- c(length(temp) - 1, length(temp))
   tempsplit <- temp[double]
   tempsplit_1 <- str_split(tempsplit[1], ":")[[1]][2]
-  tempsplit_2 <-str_split(tempsplit[2], ":")[[1]]
+  tempsplit_2 <- str_split(tempsplit[2], ":")[[1]]
   rootlength <- as.numeric(tempsplit_1) +
     as.numeric(str_split(tempsplit_2[2], ";")[[1]][1])
-  newx <- paste(")", tempsplit_2[1], ":", rootlength, ";", sep="")
+  newx <- paste0(")", tempsplit_2[1], ":", rootlength, ";")
   newpre <- str_replace(temp[1], "[(]", "")
   allelse <- temp[-1]
-  allelse <- allelse[setdiff(1:length(allelse), double-1)]
-  allelse <- paste(")", allelse, sep="")
-  tempdone <- paste(newpre, paste(allelse, collapse=""), newx, sep="")
+  allelse <- allelse[setdiff(1:length(allelse), double - 1)]
+  allelse <- paste0(")", allelse)
+  tempdone <- paste0(newpre, paste(allelse, collapse = ""), newx)
   return(tempdone)
 }
 
 colldouble <- function(z) {
-  if ( class ( try ( read.tree(text = z), silent = T ) ) %in% 'try-error')
-  { treephylo <- collapse_double_root(z) } else
-  { treephylo <- z }
+  ztry <- try( read.tree(text = z), silent = TRUE)
+  if (class(ztry) %in% 'try-error') {
+    treephylo <- collapse_double_root(z)
+  } else {
+    treephylo <- z
+  }
   return(treephylo)
 }
+
+getnewick <- function(x){
+  tree <- gsub("\n", "", x[[1]])
+  read.tree(text = colldouble(tree))
+}
