@@ -1,7 +1,6 @@
 #' This function will return ClassificationBankIDs (hierarchiesIDs) that refer to the
 #' given NamebankID
 #'
-#' @import httr XML RCurl
 #' @export
 #' @param namebankID (charcter) NameBank identifier you wish to search for in
 #'    ClassificationBank
@@ -9,7 +8,7 @@
 #'    particular classification
 #' @param keyCode Your uBio API key; loads from .Rprofile. If you don't have
 #'    one, obtain one at http://www.ubio.org/index.php?pagename=form.
-#' @param callopts Parameters passed on to httr::GET call.
+#' @param ... Parameters passed on to \code{\link[httr]{GET}}
 #' @return A data.frame with columns classificationBankID, classificationTitleID, and
 #' classificationTitle
 #' @examples \dontrun{
@@ -17,20 +16,19 @@
 #' }
 
 ubio_classification_search <- function(namebankID = NULL, classificationTitleID = NULL,
-  keyCode = NULL, callopts=list())
-{
+  keyCode = NULL, ...) {
+
   url <- "http://www.ubio.org/webservices/service.php"
   keyCode <- getkey(keyCode, "ubioApiKey")
-  args <- taxize_compact(list(
+  args <- tc(list(
     'function' = 'classificationbank_search', namebankID = namebankID,
     classificationTitleID = classificationTitleID, keyCode = keyCode))
-  tmp <- GET(url, query=args, callopts)
+  tmp <- GET(url, query = args, ...)
   stop_for_status(tmp)
   tt <- content(tmp)
   toget <- c("classificationBankID", "classificationTitleID", "classificationTitle")
-  temp <- lapply(toget, function(x) sapply(xpathApply(tt, paste("//results//seniorNames//", x, sep="")), xmlValue))
-  temp[[3]] <- sapply(temp[[3]], base64Decode, USE.NAMES = FALSE)
+  temp <- lapply(toget, function(x) sapply(xpathApply(tt, paste("//results//seniorNames//", x, sep = "")), xmlValue))
+  temp[[3]] <- sapply(temp[[3]], function(z) rawToChar(openssl::base64_decode(z)), USE.NAMES = FALSE)
   out <- data.frame(do.call(cbind, temp), stringsAsFactors = FALSE)
-  names(out) <- c("hierarchiesid", "classificationtitleid", "classificationtitle")
-  return( out )
+  setNames(out, c("hierarchiesid", "classificationtitleid", "classificationtitle"))
 }
