@@ -13,5 +13,5 @@ test_that("get_tsn accepts ask and verbose arguments", {
   expect_message(get_tsn('Dugesia', verbose=TRUE))
   expect_that(get_tsn('Dugesia', verbose=FALSE), not(shows_message()))
   
-  expect_that(is.na(get_tsn('bear', searchtype="comname", ask=FALSE, verbose=FALSE)), is_true())
+  expect_that(is.na(get_tsn('black bear', searchtype="common", ask=FALSE, verbose=FALSE)), is_true())
 })
